==> haskell-tar-conduit-0.4.1-184-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tar-conduit
version:              0.4.1
visibility:           public
id:                   tar-conduit-0.4.1-DwbvMgd7yXE7BsCXh64c4E
key:                  tar-conduit-0.4.1-DwbvMgd7yXE7BsCXh64c4E
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  ffeb62bce5869f9a7e0774760f325a5f
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tar-conduit-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tar-conduit-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tar-conduit-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.4.1-DwbvMgd7yXE7BsCXh64c4E
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI text-2.0.2
    unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-conduit-0.4.1-186-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tar-conduit
version:              0.4.1
visibility:           public
id:                   tar-conduit-0.4.1-IbFnJAoRSSZ5e98idSZxu0
key:                  tar-conduit-0.4.1-IbFnJAoRSSZ5e98idSZxu0
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  6658199f36445d85ca777468ce315f9a
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tar-conduit-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tar-conduit-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tar-conduit-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.4.1-IbFnJAoRSSZ5e98idSZxu0
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    safe-exceptions-0.1.7.4-CBGnyYEnBKB3bMqSoAV5tn text-2.0.2
    unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
